==> bonita-common-6.1.1-sources.jar: org/bonitasoft/engine/bpm/process/impl/SubProcessActivityDefinitionBuilder.java <==
/**
 * Copyright (C) 2012 BonitaSoft S.A.
 * BonitaSoft, 31 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.bpm.process.impl;

import org.bonitasoft.engine.bpm.flownode.impl.FlowElementContainerDefinitionImpl;

/**
 * @author Matthieu Chaffotte
 */
public class SubProcessActivityDefinitionBuilder extends FlowElementContainerBuilder {

    private final SubProcessDefinitionImpl subProcessActivity;

    SubProcessActivityDefinitionBuilder(final ProcessDefinitionBuilder processDefinitionBuilder, final FlowElementContainerDefinitionImpl container,
            final String name, final boolean triggeredByEvent) {
        super(container, processDefinitionBuilder);
        subProcessActivity = new SubProcessDefinitionImpl(name, triggeredByEvent);
        container.addActivity(subProcessActivity);
    }

    /**
     * @return
     *         the builder to add elements in this sub process
     */
    public SubProcessDefinitionBuilder getSubProcessBuilder() {
        return new SubProcessDefinitionBuilder(getProcessBuilder(), subProcessActivity);
    }

}

==> bonita-common-6.5.2-sources.jar: org/bonitasoft/engine/bpm/process/impl/SubProcessActivityDefinitionBuilder.java <==
/**
 * Copyright (C) 2012 BonitaSoft S.A.
 * BonitaSoft, 31 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.bpm.process.impl;

import org.bonitasoft.engine.bpm.flownode.impl.internal.FlowElementContainerDefinitionImpl;
import org.bonitasoft.engine.bpm.process.impl.internal.SubProcessDefinitionImpl;

/**
 * @author Matthieu Chaffotte
 */
public class SubProcessActivityDefinitionBuilder extends FlowElementContainerBuilder {

    private final SubProcessDefinitionImpl subProcessActivity;

    SubProcessActivityDefinitionBuilder(final ProcessDefinitionBuilder processDefinitionBuilder, final FlowElementContainerDefinitionImpl container,
            final String name, final boolean triggeredByEvent) {
        super(container, processDefinitionBuilder);
        subProcessActivity = new SubProcessDefinitionImpl(name, triggeredByEvent);
        container.addActivity(subProcessActivity);
    }

    /**
     * @return
     *         the builder to add elements in this sub process
     */
    public SubProcessDefinitionBuilder getSubProcessBuilder() {
        return new SubProcessDefinitionBuilder(getProcessBuilder(), subProcessActivity);
    }

}
